/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or (at
 *  your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 *  MA 02110-1301, USA.
 *
 *  Copyright © 2006 Pierre Habouzit
 */

#include "mime-types.h"

#include "mutt.h"

const char MimeSpecials[] = "@.,;:<>[]\\\"()?/= \t";

const char *BodyTypes[] = {
    "x-unknown",
    "audio",
    "application",
    "image",
    "message",
    "model",
    "multipart",
    "text",
    "video",
};

const char *BodyEncodings[] = {
    "x-unknown",
    "7bit",
    "8bit",
    "quoted-printable",
    "base64",
    "binary",
    "x-uuencoded",
};

void address_wipe(address_t *addr)
{
    p_delete(&addr->personal);
    p_delete(&addr->mailbox);
    address_delete(&addr->next);
}

void parameter_wipe(PARAMETER *param)
{
    p_delete(&param->attribute);
    p_delete(&param->value);
    parameter_delete(&param->next);
}

void envelope_wipe(ENVELOPE *p)
{
    address_delete(&p->return_path);
    address_delete(&p->from);
    address_delete(&p->to);
    address_delete(&p->cc);
    address_delete(&p->bcc);
    address_delete(&p->sender);
    address_delete(&p->reply_to);
    address_delete(&p->mail_followup_to);

    p_delete(&p->list_post);
    p_delete(&p->subject);
    /* real_subj is just an offset to subject and shouldn't be freed */
    p_delete(&p->message_id);
    p_delete(&p->supersedes);
    p_delete(&p->date);
    p_delete(&p->x_label);
    p_delete(&p->organization);
#ifdef USE_NNTP
    p_delete(&p->newsgroups);
    p_delete(&p->xref);
    p_delete(&p->followup_to);
    p_delete(&p->x_comment_to);
#endif

    mutt_buffer_free (&p->spam);
    mutt_free_list(&p->references);
    mutt_free_list(&p->in_reply_to);
    mutt_free_list(&p->userhdrs);
}

void header_wipe(HEADER *h)
{
    envelope_delete(&h->env);
    mutt_free_body (&h->content);
    p_delete(&h->maildir_flags);
    p_delete(&h->tree);
    p_delete(&h->path);
#ifdef MIXMASTER
    mutt_free_list(&h->chain);
#endif
    p_delete(&h->data);
}

